import { Request, Response, NextFunction } from 'express';
import { CustomLocals } from '../types/common';
import { Model } from 'mongoose';
/**
 * To config the keycloak with authorized user.
 * @param realm - The name of the realm
 * @param authUrl - The url of federated identity
 * @param clientId - Name of the client
 * @param clientSecret - The secret id of the client
 * @param username - Username of the admin
 * @param password - Password of the admin
 * @returns The keycloak config
 */
declare function keycloakConfig(realm: string, authUrl: string, clientId: string, clientSecret: string, username: string, password: string): any;
interface UserPayload {
    sid: string;
    azp: string;
    name: string;
    preferred_username: string;
    given_name: string;
    family_name: string;
    email: string;
    typ: 'Bearer';
    realm_access: object;
    resource_access: object;
}
interface CurrentUser {
    currentUser: UserPayload;
}
interface AuthMiddleware {
    currentUser<T>(User: Model<T>): (req: Request, res: Response<any, CustomLocals.CurrentUserDataLocals<T>>, next: NextFunction) => {};
}
declare class AuthMiddleware implements AuthMiddleware {
    private static _instance;
    private constructor();
    static getInstance(): AuthMiddleware;
    /**
     * Decode the access token by the jsonwebtoken package.
     * @param accessToken - Access token from the header
     * @returns The decoded user payload
     */
    private decodeAccessToken;
    /**
     * Verify the access token with online by keycloak.
     * @param accessToken - Access token from the header
     * @returns The online verified user payload
     */
    private verifyOnlineAccessToken;
    /**
     * Verify the access token with offline by keycloak.
     * @param accessToken - Access token from the header
     * @returns The offline verified user payload
     */
    private verifyOfflineAccessToken;
    /**
     * Create the user in the database.
     * @param userData - User payload contents the user data from access token
     * @param User - Mongoose model for user
     * @returns - The saved user data
     */
    private createUser;
}
export { keycloakConfig, UserPayload, CurrentUser, AuthMiddleware };
